@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2026 Zabbix SIA
+** Copyright 2001-2024 Zabbix SIA
 **
 ** Licensed under the Apache License, Version 2.0 (the "License");
 ** you may not use this file except in compliance with the License.
@@ -22,11 +22,11 @@ import (
 	"errors"
 	"time"
 
+	"git.zabbix.com/ap/plugin-support/zbxerr"
 	"go.mongodb.org/mongo-driver/bson"
 	"go.mongodb.org/mongo-driver/bson/primitive"
 	"go.mongodb.org/mongo-driver/mongo"
 	"go.mongodb.org/mongo-driver/mongo/options"
-	"golang.zabbix.com/sdk/zbxerr"
 )
 
 // OplogStatsHandler
